package net.outlyer.plugins;

/*
 * Copyright (c) 2008, Toni Corvera. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

// $Id: Sandbox.java 56 2008-06-29 00:12:05Z toni $

/**
 * Public methods provided by the sandbox.
 * Note that all methods in this interface imply a call to {@link #execute}.
 */
public interface Sandbox extends RuntimeHooks, SandboxProperties {

    /**
     * @see #createDelayedImplementation(Class, boolean)
     * @deprecated (TEMPORARILY) Until the API stabilizes,
     *  {@link #createDelayedImplementation(Class, String)} is the only
     *  secure variant.
     */
    <T> T createDelayedImplementation(final Class<T> interfaceClass) throws PluginExecutionException;

    /**
     * Creates an implementation of an interface from JS code
     * @param interfaceClass Class of the interface to implement
     * @param allowPartialImplementation If true, the implementation would be used
     * even if incomplete (note that calling an unimplemented method will produce
     * an exception)
     * @return The implementation
     * @throws net.outlyer.plugins.sandboxing.PluginExecutionException
     * @deprecated (TEMPORARILY) Until the API stabilizes,
     *  {@link #createDelayedImplementation(Class, String)} is the only
     *  secure variant.
     */
    <T> T createDelayedImplementation(final Class<T> interfaceClass,
                                      boolean allowPartialImplementation)
                                                throws PluginExecutionException;

    /**
     * @see #createDelayedImplementation(Class, boolean)
     * @param fallbackObject If not null incomplete implementations are allowed and
     * calls to undefined methods will be passed to this object
     * @deprecated (TEMPORARILY) Until the API stabilizes,
     *  {@link #createDelayedImplementation(Class, String)} is the only
     *  secure variant.
     */
    <T> T createDelayedImplementation(final Class<T> interfaceClass,
                                      final T fallbackObject)
                                                throws PluginExecutionException;

    /**
     * Creates an implementation of an interface from a JS object
     * containing the interface's methods.
     * @param interfaceClass Interface to implement
     * @param objectName Name of the JS object implementing the interface
     * @return The implementation
     * @throws net.outlyer.plugins.PluginExecutionException
     */
    <T> T createDelayedImplementation(final Class<T> interfaceClass, final String objectName) throws PluginExecutionException;

    /**
     * Run the script
     */
    void execute() throws PluginExecutionException;

    /**
     * Obtains object containing the plugin object
     * @see #getPluginName
     * @return Plugin object associated to this sandbox
     */
    BasePluginObject getPluginObject() throws PluginExecutionException;
}
